# ResultViewer

[![Generic badge](https://img.shields.io/badge/Python-3.7|3.8|3.9|3.10-<COLOR>.svg)](https://shields.io/)
[![Generic badge](https://img.shields.io/badge/OS-Windows|Ubuntu-<COLOR>.svg)](https://shields.io/)
